View Source Reginald.Backends.Registry.Supervisor (Reginald v0.0.2-rc.0.0.1)
Reginald.Backends.Registry.Supervisor is the main entrypoint for raising all of the necessary child components for running Reginald.Backends.Registry.
You should probably never reference it directly, and instead use the public API module Reginald.
Summary
Functions
Returns a specification to start this module under a supervisor.
Starts the Backends.Registry.Supervisor.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
@spec start_link(Keyword.t()) :: Supervisor.on_start()
Starts the Backends.Registry.Supervisor.
Passed options must include a :name and a :keys value, which must be either :unique or :duplicate.
In addition to the :name and the :keys values, we also allow passing all of the native Registry.start_link/1 options.